@@ -1,3 +1,7 @@
+import sys
+
+import pytest
+
 from . import check, v
 assert v  # Silence pyflakes.
 
@@ -12,6 +16,18 @@ def test_new_format_string(v):
     check(v.used_names, ['a', 'b', 'c', 'd', 'locals'])
 
 
+@pytest.mark.skipif(
+    sys.version_info < (3, 6),
+    reason="needs f-string support (added in Python 3.6)")
+def test_f_string(v):
+    v.scan('''\
+f'{a}, {b:0d} {c:<30} {d:.2%} {e()} {f:{width}.{precision}}'
+f'{ {x:y for (x, y) in ((1, 2), (3, 4))} }'
+''')
+    check(v.used_names,
+          ['a', 'b', 'c', 'd', 'e', 'f', 'precision', 'width', 'x', 'y'])
+
+
 def test_new_format_string_access(v):
     v.scan("'{a.b}, {c.d.e} {f[g]} {h[i][j]}'.format(**locals())")
     check(v.used_names, ['a', 'c', 'f', 'h', 'locals'])
