@@ -1,3 +1,7 @@
+import sys
+
+import pytest
+
 from . import check, skip_if_not_has_async, v
 assert v  # Silence pyflakes.
 
@@ -516,23 +520,6 @@ def foo(*bar):
     check(v.unused_vars, ['bar'])
 
 
-def test_encoding1(v):
-    v.scan(u"""\
-# -*- coding: utf-8 -*-
-pass
-""")
-    assert True
-
-
-def test_encoding2(v):
-    v.scan(u"""\
-#! /usr/bin/env python
-# -*- coding: utf-8 -*-
-pass
-""")
-    assert True
-
-
 def test_multiple_definition(v):
     v.scan("""\
 a = 1
@@ -541,3 +528,48 @@ a = 2
     check(v.defined_vars, ['a', 'a'])
     check(v.used_names, [])
     check(v.unused_vars, ['a', 'a'])
+
+
+@pytest.mark.skipif(sys.version_info < (3, 5),
+                    reason="requires Python 3.5+")
+def test_arg_type_annotation(v):
+    v.scan("""\
+from typing import Iterable
+
+def f(n: int) -> Iterable[int]:
+    yield n
+""")
+
+    check(v.unused_vars, [])
+    check(v.unused_funcs, ['f'])
+    check(v.unused_imports, [])
+
+
+@pytest.mark.skipif(sys.version_info < (3, 6),
+                    reason="requires Python 3.6+")
+def test_var_type_annotation(v):
+    v.scan("""\
+from typing import List
+
+x: List[int] = [1]
+""")
+
+    check(v.unused_vars, ['x'])
+    check(v.unused_funcs, [])
+    check(v.unused_imports, [])
+
+
+def test_type_hint_comments(v):
+    v.scan("""\
+import typing
+
+if typing.TYPE_CHECKING:
+    from typing import List, Text
+
+def foo(foo_li):
+    # type: (List[Text]) -> None
+    for bar in foo_li:
+        bar.xyz()
+""")
+
+    check(v.unused_imports, ['List', 'Text'])
