@@ -36,7 +36,7 @@ def check_size(example, size):
             assert count_lines(node) == size
             break
     else:
-        assert False, 'Failed to find top-level class "Foo" in code'
+        raise AssertionError('Failed to find top-level class "Foo" in code')
 
 
 def test_size_basic():
@@ -78,7 +78,10 @@ class Foo(object):
         else:
             pass
 """
-    check_size(example, 11)
+    size = 11
+    if sys.version_info >= (3, 8):
+        size = 10
+    check_size(example, size)
 
 
 def test_size_while():
